@@ -1,10 +1,10 @@
 # coding=utf-8
-import ConfigParser
+import configparser
 
 
 def init(path):
     global cf
-    cf = ConfigParser.ConfigParser()
+    cf = configparser.RawConfigParser()
     cf.read(path)
 
 
