@@ -22,4 +22,4 @@ def del_v(name):
     try:
         del _global_dict[name]
     except:
-        print traceback.print_exc()
+        print(traceback.print_exc())
