@@ -16,7 +16,7 @@ class LoggerUtils(object):
         formatter = logging.Formatter(log_fmt)
         log_file_handler = TimedRotatingFileHandler(
             filename='./logs/%s.log' % filename, when="H", interval=1,
-            backupCount=24)
+            backupCount=24, encoding='utf-8')
         log_file_handler.suffix = "%Y-%m-%d_%H.log"
         log_file_handler.extMatch = re.compile(r"^\d{4}-\d{2}-\d{2}_\d{2}-\d{2}.log$")
         log_file_handler.setFormatter(formatter)
